
html {
  font-size: 18px;
}

#main-container {
  width: 80%;
  font-family: Sans-Serif;
  font-size: 20px;
  margin-left: auto;
  margin-right: auto
}

#tab-content-container {
  margin: 20px;
}

#data-table {
  font-size: 14px;
  line-height: 14px;
}

#data-table td {
  padding-top: 0;
  padding-bottom: 0;
}

.plot-button {
    border: 1px solid #ccc;
    background-color: #f9f9f9;
    cursor: pointer;
}

.plot-button.selected {
    background-color: #007bff;
    color: white;
    border-color: #007bff;
}
